@@ -97,7 +97,7 @@ def _datastream(check_continue_func, host=HOST, port=PORT):
 				ddict = dict(zip(brain_parameters, _extract_tuple(data)))
 				yield ddict
 			elif u'blinkStrength' in data:
-				yield {blinkStrength:data[blinkStrength]}
+				yield {u'blinkStrength':data[u'blinkStrength']}
 			else:
 				continue
 		else:
